@@ -472,6 +472,11 @@ gpb.cv <- function(params = list()
           cluster_ids <- cluster_ids[train_indexDT$indices]
         }
         
+        weights <- gp_model$get_weights()
+        if (!is.null(weights)) {
+          weights <- weights[train_indexDT$indices]
+        }
+        
         gp_model_train <- gpb.GPModel$new(likelihood = gp_model$get_likelihood_name()
                                           , group_data = group_data
                                           , group_rand_coef_data = group_rand_coef_data
@@ -483,6 +488,9 @@ gpb.cv <- function(params = list()
                                           , cov_fct_shape = gp_model$.__enclos_env__$private$cov_fct_shape
                                           , gp_approx = gp_model$.__enclos_env__$private$gp_approx
                                           , num_parallel_threads = gp_model$.__enclos_env__$private$num_parallel_threads
+                                          , matrix_inversion_method = gp_model$.__enclos_env__$private$matrix_inversion_method
+                                          , weights = weights
+                                          , likelihood_learning_rate = gp_model$.__enclos_env__$private$likelihood_learning_rate
                                           , cov_fct_taper_range = gp_model$.__enclos_env__$private$cov_fct_taper_range
                                           , cov_fct_taper_shape = gp_model$.__enclos_env__$private$cov_fct_taper_shape
                                           , num_neighbors = gp_model$.__enclos_env__$private$num_neighbors
@@ -490,11 +498,11 @@ gpb.cv <- function(params = list()
                                           , ind_points_selection = gp_model$.__enclos_env__$private$ind_points_selection
                                           , num_ind_points = gp_model$.__enclos_env__$private$num_ind_points
                                           , cover_tree_radius = gp_model$.__enclos_env__$private$cover_tree_radius
-                                          , matrix_inversion_method = gp_model$.__enclos_env__$private$matrix_inversion_method
                                           , seed = gp_model$.__enclos_env__$private$seed
                                           , cluster_ids = cluster_ids
                                           , likelihood_additional_param = gp_model$.__enclos_env__$private$likelihood_additional_param
                                           , free_raw_data = TRUE)
+        
         valid_set_gp <- NULL
         if (use_gp_model_for_validation) {
           gp_model_train$set_prediction_data(group_data_pred = group_data_pred
@@ -695,7 +703,7 @@ gpb.cv <- function(params = list()
   }
   if (delete_boosters_folds) {
     lapply(cv_booster$boosters, function(fd) {
-      fd$booster$finalize()
+      fd$booster$.__enclos_env__$private$finalize()
     })
     cv_booster$boosters = NULL
   }
