@@ -727,6 +727,8 @@ GPBOOST_C_EXPORT SEXP GPB_REModelFree_R(
 * \param init_aux_pars Initial values for values for aux_pars_ (e.g., shape parameter of gamma likelihood)
 * \param estimate_aux_pars If true, any additional parameters for non-Gaussian likelihoods are also estimated (e.g., shape parameter of gamma likelihood)
 * \param estimate_cov_par_index If estimate_cov_par_index[0] >= 0, some covariance parameters might not be estimated, estimate_cov_par_index[i] is then bool and indicates which ones are estimated
+* \param m_lbfgs Number of corrections to approximate the inverse Hessian matrix for the lbfgs optimizer
+* \param delta_conv_mode_finding Used for checking convergence in mode finding algorithm for non-Gaussian likelihoods
 * \return 0 when succeed, -1 when failure happens
 */
 GPBOOST_C_EXPORT SEXP GPB_SetOptimConfig_R(
@@ -758,7 +760,9 @@ GPBOOST_C_EXPORT SEXP GPB_SetOptimConfig_R(
 	SEXP piv_chol_rank,
 	SEXP init_aux_pars,
 	SEXP estimate_aux_pars,
-	SEXP estimate_cov_par_index
+	SEXP estimate_cov_par_index,
+	SEXP m_lbfgs,
+	SEXP delta_conv_mode_finding
 );
 
 /*!
