@@ -159,6 +159,8 @@ namespace GPBoost {
 		* \param init_aux_pars Initial values for values for aux_pars_ (e.g., shape parameter of gamma likelihood)
 		* \param estimate_aux_pars If true, any additional parameters for non-Gaussian likelihoods are also estimated (e.g., shape parameter of gamma likelihood)
 		* \param estimate_cov_par_index If estimate_cov_par_index[0] >= 0, some covariance parameters might not be estimated, estimate_cov_par_index[i] is then bool and indicates which ones are estimated
+		* \param m_lbfgs Number of corrections to approximate the inverse Hessian matrix for the lbfgs optimizer
+		* \param delta_conv_mode_finding Used for checking convergence in mode finding algorithm for non-Gaussian likelihoods
 		*/
 		void SetOptimConfig(double* init_cov_pars,
 			double lr,
@@ -187,7 +189,9 @@ namespace GPBoost {
 			int piv_chol_rank,
 			double* init_aux_pars,
 			bool estimate_aux_pars,
-			const int* estimate_cov_par_index);
+			const int* estimate_cov_par_index,
+			int m_lbfgs,
+			double delta_conv_mode_finding);
 
 		/*!
 		* \brief Reset cov_pars_ (to their initial values).
@@ -436,9 +440,9 @@ namespace GPBoost {
 		int NumAuxPars() const;
 
 		/*!
-		* \brief Get additional likelihood parameters (e.g., shape parameter for a gamma likelihood)
+		* \brief Get additional likelihood parameters (e.g., shape parameter for a gamma likelihood, on original scale)
 		* \param[out] aux_pars Additional likelihood parameters (aux_pars_). This vector needs to be pre-allocated
-		* \param[out] name Name of the first parameter
+		* \param[out] name Name of the parameters (separated by "_SEP_" if there are multiple parameters)
 		*/
 		void GetAuxPars(double* aux_pars,
 			string_t& name) const;
